*****************************************
goodplay: Make your deployment play well.
*****************************************

goodplay enables you to test your deployments and distributed software
infrastructure by reusing your existing knowledge of Ansible_.

.. _Ansible: https://github.com/ansible/ansible


.. toctree::
   :caption: User Documentation

This part of the documentation, which is mostly prose, begins with some
background information about goodplay, then focuses on step-by-step
instructions for digging deeper into what can be accomplished with goodplay.

.. toctree::
   :maxdepth: 2

   user/intro
   user/quickstart
   user/install
   user/faq


.. toctree::
   :caption: Feature Documentation

All features provided by goodplay are documented in this section.
So if you're trying to use a specific feature you should find all the details here.

.. toctree::
   :maxdepth: 2

   feature/environment
   feature/test-playbook
   feature/dependencies
   feature/cmdline
   feature/integration


.. toctree::
   :caption: Real-World Examples

In case you need some inspiration you should have a look at our real-world
examples that showcase how goodplay is used in the wild.

.. toctree::
   :maxdepth: 1

   examples/index


.. toctree::
   :caption: Contributor Documentation

If you want to contribute to the project, this part of the documentation is for
you.

.. toctree::
   :maxdepth: 1

   dev/contributing
   dev/authors

.. include:: ../../HISTORY.rst
